Available Kernels
===================

.. toctree::
  :maxdepth: 1

   Kernels for fixed-vector input <fixed_vec_kernels.rst>

   Kernels for sequence data <sequence_kernels.rst>

   Kernels for graphs <graph_kernels.rst>

   Feature extractors for sequences and graphs <static_layers.rst>

